@@ -1,6 +1,6 @@
 use std::{cell::RefCell, collections::HashMap, rc::Rc, sync::Arc};
 
-use criterion::{black_box, criterion_group, criterion_main, Criterion};
+use criterion::{Criterion, black_box, criterion_group, criterion_main};
 use floem::{
     reactive::Scope,
     text::{Attrs, AttrsList, FamilyOwned, TextLayout, Wrap},
@@ -28,7 +28,7 @@ struct TLProv<'a> {
     font_family: Vec<FamilyOwned>,
     has_multiline_phantom: bool,
 }
-impl<'a> TextLayoutProvider for TLProv<'a> {
+impl TextLayoutProvider for TLProv<'_> {
     fn text(&self) -> Rope {
         self.text.clone()
     }
@@ -70,7 +70,7 @@ impl<'a> TextLayoutProvider for TLProv<'a> {
         let attrs = Attrs::new()
             .family(&self.font_family)
             .font_size(font_size as f32);
-        let mut attrs_list = AttrsList::new(attrs);
+        let mut attrs_list = AttrsList::new(attrs.clone());
 
         // We don't do line styles, since they aren't relevant
 
@@ -79,7 +79,7 @@ impl<'a> TextLayoutProvider for TLProv<'a> {
             let start = col + offset;
             let end = start + size;
 
-            let mut attrs = attrs;
+            let mut attrs = attrs.clone();
             if let Some(fg) = phantom.fg {
                 attrs = attrs.color(fg);
             }
