@@ -6,22 +6,24 @@ use std::{
     path::{Path, PathBuf},
     rc::Rc,
     sync::{
-        atomic::{self, AtomicUsize},
         Arc,
+        atomic::{self, AtomicUsize},
     },
     time::Duration,
 };
 
 use floem::{
+    ViewId,
     action::exec_after,
     ext_event::create_ext_action,
     keyboard::Modifiers,
     peniko::Color,
     reactive::{
-        batch, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith, batch,
     },
     text::{Attrs, AttrsList, FamilyOwned, TextLayout},
     views::editor::{
+        CursorInfo, Editor, EditorStyle,
         actions::CommonAction,
         command::{Command, CommandExecuted},
         id::EditorId,
@@ -29,16 +31,14 @@ use floem::{
         phantom_text::{PhantomText, PhantomTextKind, PhantomTextLine},
         text::{Document, DocumentPhantom, PreeditData, Styling, SystemClipboard},
         view::{ScreenLines, ScreenLinesBase},
-        CursorInfo, Editor, EditorStyle,
     },
-    ViewId,
 };
 use itertools::Itertools;
 use lapce_core::{
     buffer::{
-        diff::{rope_diff, DiffLines},
-        rope_text::RopeText,
         Buffer, InvalLines,
+        diff::{DiffLines, rope_diff},
+        rope_text::RopeText,
     },
     char_buffer::CharBuffer,
     command::EditCommand,
@@ -52,8 +52,8 @@ use lapce_core::{
     rope_text_pos::RopeTextPosition,
     selection::{InsertDrift, Selection},
     style::line_styles,
-    syntax::{edit::SyntaxEdit, BracketParser, Syntax},
-    word::{get_char_property, CharClassification, WordCursor},
+    syntax::{BracketParser, Syntax, edit::SyntaxEdit},
+    word::{CharClassification, WordCursor, get_char_property},
 };
 use lapce_rpc::{
     buffer::BufferId,
@@ -62,20 +62,20 @@ use lapce_rpc::{
     style::{LineStyle, LineStyles, Style},
 };
 use lapce_xi_rope::{
-    spans::{Spans, SpansBuilder},
     Interval, Rope, RopeDelta, Transformer,
+    spans::{Spans, SpansBuilder},
 };
 use lsp_types::{
     CodeActionOrCommand, CodeLens, Diagnostic, DiagnosticSeverity,
-    DocumentSymbolResponse, InlayHint, InlayHintLabel,
+    DocumentSymbolResponse, InlayHint, InlayHintLabel, TextEdit,
 };
 use serde::{Deserialize, Serialize};
 use smallvec::SmallVec;
 
 use crate::{
     command::{CommandKind, LapceCommand},
-    config::{color::LapceColor, LapceConfig},
-    editor::{compute_screen_lines, EditorData},
+    config::{LapceConfig, color::LapceColor},
+    editor::{EditorData, compute_screen_lines, gutter::FoldingRanges},
     find::{Find, FindProgress, FindResult},
     history::DocumentHistory,
     keypress::KeyPressFocus,
@@ -180,7 +180,7 @@ pub struct Doc {
     /// (line, col)
     pub completion_pos: RwSignal<(usize, usize)>,
 
-    /// Current inline completion text, if any.  
+    /// Current inline completion text, if any.
     /// This will be displayed even on views that are not focused.
     pub inline_completion: RwSignal<Option<String>>,
     /// (line, col)
@@ -191,6 +191,8 @@ pub struct Doc {
 
     pub code_lens: RwSignal<AllCodeLens>,
 
+    pub folding_ranges: RwSignal<FoldingRanges>,
+
     /// Stores information about different versions of the document from source control.
     histories: RwSignal<im::HashMap<String, DocumentHistory>>,
     pub head_changes: RwSignal<im::Vector<DiffLines>>,
@@ -257,6 +259,7 @@ impl Doc {
             common,
             code_lens: cx.create_rw_signal(im::HashMap::new()),
             document_symbol_data: cx.create_rw_signal(None),
+            folding_ranges: cx.create_rw_signal(FoldingRanges::default()),
         }
     }
 
@@ -307,6 +310,7 @@ impl Doc {
             common,
             code_lens: cx.create_rw_signal(im::HashMap::new()),
             document_symbol_data: cx.create_rw_signal(None),
+            folding_ranges: cx.create_rw_signal(FoldingRanges::default()),
         }
     }
 
@@ -357,6 +361,7 @@ impl Doc {
             common,
             code_lens: cx.create_rw_signal(im::HashMap::new()),
             document_symbol_data: cx.create_rw_signal(None),
+            folding_ranges: cx.create_rw_signal(FoldingRanges::default()),
         }
     }
 
@@ -631,7 +636,7 @@ impl Doc {
         self.buffer.with_untracked(|b| b.rev())
     }
 
-    /// Get the buffer's line-ending.  
+    /// Get the buffer's line-ending.
     /// Note: this may not be the same as what the actual line endings in the file are, rather this
     /// is what the line-ending is set to (and what it will be saved as).
     pub fn line_ending(&self) -> LineEnding {
@@ -651,6 +656,7 @@ impl Doc {
             self.clear_style_cache();
             self.get_code_lens();
             self.get_document_symbol();
+            self.get_folding_range();
         });
     }
 
@@ -674,14 +680,34 @@ impl Doc {
         }
     }
 
+    pub fn do_text_edit(&self, edits: &[TextEdit]) {
+        let edits = self.buffer.with_untracked(|buffer| {
+            edits
+                .iter()
+                .map(|edit| {
+                    let selection = lapce_core::selection::Selection::region(
+                        buffer.offset_of_position(&edit.range.start),
+                        buffer.offset_of_position(&edit.range.end),
+                    );
+                    (selection, edit.new_text.as_str())
+                })
+                .collect::<Vec<_>>()
+        });
+        self.do_raw_edit(&edits, EditType::Completion);
+    }
+
     fn check_auto_save(&self) {
         let config = self.common.config.get_untracked();
         if config.editor.autosave_interval > 0 {
-            if !self.content.with_untracked(|c| c.is_file()) {
+            let Some(path) = self.content.with_untracked(|c| c.path().cloned())
+            else {
                 return;
             };
             let rev = self.rev();
             let doc = self.clone();
+            let scope = self.scope;
+            let proxy = self.common.proxy.clone();
+            let format = config.editor.format_on_save;
             exec_after(
                 Duration::from_millis(config.editor.autosave_interval),
                 move |_| {
@@ -697,7 +723,26 @@ impl Doc {
                         return;
                     }
 
-                    doc.save(|| {});
+                    if format {
+                        let send = create_ext_action(scope, move |result| {
+                            let current_rev = doc.rev();
+                            if current_rev != rev {
+                                return;
+                            }
+                            if let Ok(ProxyResponse::GetDocumentFormatting {
+                                edits,
+                            }) = result
+                            {
+                                doc.do_text_edit(&edits);
+                            }
+                            doc.save(|| {});
+                        });
+                        proxy.get_document_formatting(path, move |result| {
+                            send(result);
+                        });
+                    } else {
+                        doc.save(|| {});
+                    }
                 },
             );
         }
@@ -944,7 +989,7 @@ impl Doc {
                                     })
                                     .collect(),
                             };
-                        let symbol_new = Some(SymbolData { items, path });
+                        let symbol_new = Some(SymbolData::new(items, path, cx));
                         doc.document_symbol_data.update(|symbol| {
                             *symbol = symbol_new;
                         });
@@ -959,7 +1004,7 @@ impl Doc {
     }
 
     /// Request inlay hints for the buffer from the LSP through the proxy.
-    fn get_inlay_hints(&self) {
+    pub fn get_inlay_hints(&self) {
         if !self.loaded() {
             return;
         }
@@ -1043,6 +1088,43 @@ impl Doc {
         self.clear_code_actions();
     }
 
+    pub fn get_folding_range(&self) {
+        // let cx = self.scope;
+        // let doc = self.clone();
+        // let rev = self.rev();
+        // if let DocContent::File { path, .. } = doc.content.get_untracked() {
+        //     let send = create_ext_action(cx, {
+        //         move |result| {
+        //             if rev != doc.rev() {
+        //                 return;
+        //             }
+        //             if let Ok(ProxyResponse::LspFoldingRangeResponse {
+        //                 resp, ..
+        //             }) = result
+        //             {
+        //                 let folding = resp
+        //                     .unwrap_or_default()
+        //                     .into_iter()
+        //                     .map(|x| {
+        //                         crate::editor::gutter::FoldingRange::from_lsp(x)
+        //                     })
+        //                     .sorted_by(|x, y| x.start.line.cmp(&y.start.line))
+        //                     .collect();
+        //                 doc.folding_ranges.update(|symbol| {
+        //                     symbol.0 = folding;
+        //                 });
+        //             }
+        //         }
+        //     });
+
+        //     self.common
+        //         .proxy
+        //         .get_lsp_folding_range(path, move |result| {
+        //             send(result);
+        //         });
+        // }
+    }
+
     /// Get the current completion lens text
     pub fn completion_lens(&self) -> Option<String> {
         self.completion_lens.get_untracked()
@@ -1183,7 +1265,7 @@ impl Doc {
             .set(FindProgress::InProgress(Selection::new()));
 
         let find_result = self.find_result.clone();
-        let send = create_ext_action(self.scope, move |occurrences| {
+        let send = create_ext_action(self.scope, move |occurrences: Selection| {
             find_result.occurrences.set(occurrences);
             find_result.progress.set(FindProgress::Ready);
         });
@@ -1220,11 +1302,7 @@ impl Doc {
                         .iter()
                         .filter_map(|offset| {
                             let l = buffer.line_of_offset(*offset);
-                            if l <= line {
-                                Some(l)
-                            } else {
-                                None
-                            }
+                            if l <= line { Some(l) } else { None }
                         })
                         .dedup()
                         .sorted()
@@ -1671,15 +1749,18 @@ impl DocumentPhantom for Doc {
                                         config.color(theme_prop)
                                     };
 
-                                    let text = if config.editor.error_lens_multiline
-                                    {
-                                        format!("    {}", diag.message)
-                                    } else {
-                                        format!(
-                                            "    {}",
-                                            diag.message.lines().join(" ")
-                                        )
-                                    };
+                                    let text =
+                                        if config.editor.only_render_error_styling {
+                                            "".to_string()
+                                        } else if config.editor.error_lens_multiline
+                                        {
+                                            format!("    {}", diag.message)
+                                        } else {
+                                            format!(
+                                                "    {}",
+                                                diag.message.lines().join(" ")
+                                            )
+                                        };
                                     Some(PhantomText {
                                         kind: PhantomTextKind::Diagnostic,
                                         col: end_offset - start_offset,
@@ -1839,7 +1920,8 @@ impl DocStyling {
                     if let Some(fg_color) = config.style_color(fg_color) {
                         let start = phantom_text.col_at(bracket_style.start);
                         let end = phantom_text.col_at(bracket_style.end);
-                        attrs_list.add_span(start..end, attrs.color(fg_color));
+                        attrs_list
+                            .add_span(start..end, attrs.clone().color(fg_color));
                     }
                 }
             }
@@ -1925,7 +2007,7 @@ impl Styling for DocStyling {
                 if let Some(fg_color) = config.style_color(fg_color) {
                     let start = phantom_text.col_at(line_style.start);
                     let end = phantom_text.col_at(line_style.end);
-                    attrs_list.add_span(start..end, default.color(fg_color));
+                    attrs_list.add_span(start..end, default.clone().color(fg_color));
                 }
             }
         }
@@ -1980,11 +2062,7 @@ impl Styling for DocStyling {
                         && end >= start_offset
                         && diag.severity < Some(DiagnosticSeverity::HINT)
                     {
-                        let start = if start > start_offset {
-                            start - start_offset
-                        } else {
-                            0
-                        };
+                        let start = start.saturating_sub(start_offset);
                         let end = end - start_offset;
                         let start = phantom_text.col_after(start, true);
                         let end = phantom_text.col_after(end, false);
