@@ -1,14 +1,14 @@
 use floem::{
+    Renderer, View, ViewId,
     peniko::{
-        kurbo::{Point, Rect},
         Color,
+        kurbo::{Point, Rect},
     },
     prop_extractor,
     reactive::create_effect,
     style::{FontFamily, FontSize, LineHeight, Style, TextColor},
     taffy::prelude::NodeId,
     text::{Attrs, AttrsList, FamilyOwned, TextLayout, Weight},
-    Renderer, View, ViewId,
 };
 
 prop_extractor! {
@@ -52,7 +52,7 @@ pub fn focus_text(
         id,
         text: "".to_string(),
         text_layout: None,
-        focus_color: Color::default(),
+        focus_color: Color::BLACK,
         focus_indices: Vec::new(),
         text_node: None,
         available_text: None,
@@ -77,7 +77,8 @@ pub struct FocusText {
 
 impl FocusText {
     fn set_text_layout(&mut self) {
-        let mut attrs = Attrs::new().color(self.style.color().unwrap_or_default());
+        let mut attrs =
+            Attrs::new().color(self.style.color().unwrap_or(Color::BLACK));
         if let Some(font_size) = self.style.font_size() {
             attrs = attrs.font_size(font_size);
         }
@@ -93,7 +94,7 @@ impl FocusText {
             attrs = attrs.line_height(line_height);
         }
 
-        let mut attrs_list = AttrsList::new(attrs);
+        let mut attrs_list = AttrsList::new(attrs.clone());
 
         for &i_start in &self.focus_indices {
             let i_end = self
@@ -108,7 +109,7 @@ impl FocusText {
             };
             attrs_list.add_span(
                 i_start..i_end,
-                attrs.color(self.focus_color).weight(Weight::BOLD),
+                attrs.clone().color(self.focus_color).weight(Weight::BOLD),
             );
         }
         let mut text_layout = TextLayout::new();
@@ -119,7 +120,7 @@ impl FocusText {
             let new_text_len = new_text.len();
 
             let mut attrs =
-                Attrs::new().color(self.style.color().unwrap_or_default());
+                Attrs::new().color(self.style.color().unwrap_or(Color::BLACK));
             if let Some(font_size) = self.style.font_size() {
                 attrs = attrs.font_size(font_size);
             }
@@ -132,7 +133,7 @@ impl FocusText {
                 attrs = attrs.family(font_family);
             }
 
-            let mut attrs_list = AttrsList::new(attrs);
+            let mut attrs_list = AttrsList::new(attrs.clone());
 
             for &i_start in &self.focus_indices {
                 if i_start + 3 > new_text_len {
@@ -150,7 +151,7 @@ impl FocusText {
                 };
                 attrs_list.add_span(
                     i_start..i_end,
-                    attrs.color(self.focus_color).weight(Weight::BOLD),
+                    attrs.clone().color(self.focus_color).weight(Weight::BOLD),
                 );
             }
             let mut text_layout = TextLayout::new();
@@ -233,7 +234,7 @@ impl View for FocusText {
                 let mut attrs = Attrs::new().color(
                     self.style
                         .color()
-                        .unwrap_or_else(|| Color::rgb8(0xf0, 0xf0, 0xea)),
+                        .unwrap_or_else(|| Color::from_rgb8(0xf0, 0xf0, 0xea)),
                 );
                 if let Some(font_size) = self.style.font_size() {
                     attrs = attrs.font_size(font_size);
