@@ -2,6 +2,7 @@ pub mod about;
 pub mod alert;
 pub mod app;
 pub mod code_action;
+pub mod code_lens;
 pub mod command;
 pub mod completion;
 pub mod config;
@@ -21,6 +22,7 @@ pub mod inline_completion;
 pub mod keymap;
 pub mod keypress;
 pub mod listener;
+pub mod lsp;
 pub mod main_split;
 pub mod markdown;
 pub mod palette;
@@ -36,6 +38,7 @@ pub mod terminal;
 pub mod text_area;
 pub mod text_input;
 pub mod title;
+pub mod tracing;
 pub mod update;
 pub mod wave;
 pub mod web_link;
