@@ -1,36 +1,37 @@
 use std::{collections::BTreeMap, rc::Rc, sync::Arc, time::Duration};
 
 use floem::{
-    action::{add_overlay, exec_after, remove_overlay, TimerToken},
+    IntoView, View,
+    action::{TimerToken, add_overlay, exec_after, remove_overlay},
     event::EventListener,
     keyboard::Modifiers,
     peniko::kurbo::{Point, Rect, Size},
     reactive::{
-        create_effect, create_memo, create_rw_signal, Memo, ReadSignal, RwSignal,
-        Scope, SignalGet, SignalUpdate, SignalWith,
+        Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        create_effect, create_memo, create_rw_signal,
     },
     style::CursorStyle,
     text::{Attrs, AttrsList, FamilyOwned, TextLayout},
     views::{
-        container, dyn_stack, empty, label,
-        scroll::{scroll, PropagatePointerWheel},
-        stack, svg, text, virtual_stack, Decorators, VirtualDirection,
-        VirtualItemSize, VirtualVector,
+        Decorators, VirtualVector, container, dyn_stack, empty, label,
+        scroll::{PropagatePointerWheel, scroll},
+        stack, svg, text, virtual_stack,
     },
-    IntoView, View,
 };
 use indexmap::IndexMap;
 use inflector::Inflector;
-use lapce_core::mode::Mode;
+use lapce_core::{buffer::rope_text::RopeText, mode::Mode};
 use lapce_rpc::plugin::VoltID;
 use lapce_xi_rope::Rope;
 use serde::Serialize;
+use serde_json::Value;
 
 use crate::{
     command::CommandExecuted,
     config::{
-        color::LapceColor, core::CoreConfig, editor::EditorConfig, icon::LapceIcons,
-        terminal::TerminalConfig, ui::UIConfig, DropdownInfo, LapceConfig,
+        DropdownInfo, LapceConfig, color::LapceColor, core::CoreConfig,
+        editor::EditorConfig, icon::LapceIcons, terminal::TerminalConfig,
+        ui::UIConfig,
     },
     keypress::KeyPressFocus,
     main_split::Editors,
@@ -74,6 +75,7 @@ struct SettingsItem {
     description: String,
     filter_text: String,
     value: SettingsValue,
+    serde_value: Value,
     pos: RwSignal<Point>,
     size: RwSignal<Size>,
     // this is only the header that give an visual sepeartion between different type of settings
@@ -82,8 +84,8 @@ struct SettingsItem {
 
 #[derive(Clone, Debug)]
 struct SettingsData {
-    items: im::Vector<SettingsItem>,
-    kinds: im::Vector<(String, RwSignal<Point>)>,
+    items: RwSignal<im::Vector<SettingsItem>>,
+    kinds: RwSignal<im::Vector<(String, RwSignal<Point>)>>,
     plugin_items: RwSignal<im::Vector<SettingsItem>>,
     plugin_kinds: RwSignal<im::Vector<(String, RwSignal<Point>)>>,
     filtered_items: RwSignal<im::Vector<SettingsItem>>,
@@ -142,91 +144,104 @@ impl SettingsData {
             }
         }
 
-        let config = common.config.get_untracked();
-        let mut items = im::Vector::new();
-        let mut kinds = im::Vector::new();
-        let mut item_height_accum = 0.0;
-
-        for (kind, fields, descs, mut settings_map) in [
-            (
-                "Core",
-                &CoreConfig::FIELDS[..],
-                &CoreConfig::DESCS[..],
-                into_settings_map(&config.core),
-            ),
-            (
-                "Editor",
-                &EditorConfig::FIELDS[..],
-                &EditorConfig::DESCS[..],
-                into_settings_map(&config.editor),
-            ),
-            (
-                "UI",
-                &UIConfig::FIELDS[..],
-                &UIConfig::DESCS[..],
-                into_settings_map(&config.ui),
-            ),
-            (
-                "Terminal",
-                &TerminalConfig::FIELDS[..],
-                &TerminalConfig::DESCS[..],
-                into_settings_map(&config.terminal),
-            ),
-        ] {
-            let pos = cx.create_rw_signal(Point::new(0.0, item_height_accum));
-            items.push_back(SettingsItem {
-                kind: kind.to_string(),
-                name: "".to_string(),
-                field: "".to_string(),
-                filter_text: "".to_string(),
-                description: "".to_string(),
-                value: SettingsValue::Empty,
-                pos,
-                size: cx.create_rw_signal(Size::ZERO),
-                header: true,
-            });
-            kinds.push_back((kind.to_string(), pos));
-            for (name, desc) in fields.iter().zip(descs.iter()) {
-                let field = name.replace('_', "-");
-
-                let value = if let Some(dropdown) =
-                    config.get_dropdown_info(&kind.to_lowercase(), &field)
-                {
-                    SettingsValue::Dropdown(dropdown)
-                } else {
-                    let value = settings_map.remove(&field).unwrap();
-                    SettingsValue::from(value)
-                };
-
-                let name =
-                    format!("{kind}: {}", name.replace('_', " ").to_title_case());
-                let kind = kind.to_lowercase();
-                let filter_text = format!("{kind} {name} {desc}").to_lowercase();
-                let filter_text =
-                    format!("{filter_text}{}", filter_text.replace(' ', ""));
-                items.push_back(SettingsItem {
-                    kind,
-                    name,
-                    field,
-                    filter_text,
-                    description: desc.to_string(),
-                    value,
-                    pos: cx.create_rw_signal(Point::ZERO),
-                    size: cx.create_rw_signal(Size::ZERO),
-                    header: false,
-                });
-                item_height_accum += 50.0;
-            }
-        }
-
+        let config = common.config;
         let plugin_items = cx.create_rw_signal(im::Vector::new());
         let plugin_kinds = cx.create_rw_signal(im::Vector::new());
-
+        let filtered_items = cx.create_rw_signal(im::Vector::new());
+        let items = cx.create_rw_signal(im::Vector::new());
+        let kinds = cx.create_rw_signal(im::Vector::new());
         cx.create_effect(move |_| {
-            let mut item_height_accum = item_height_accum;
+            let config = config.get();
+
+            let mut data_items = im::Vector::new();
+            let mut data_kinds = im::Vector::new();
+            let mut item_height_accum = 0.0;
+            for (kind, fields, descs, mut settings_map) in [
+                (
+                    "Core",
+                    &CoreConfig::FIELDS[..],
+                    &CoreConfig::DESCS[..],
+                    into_settings_map(&config.core),
+                ),
+                (
+                    "Editor",
+                    &EditorConfig::FIELDS[..],
+                    &EditorConfig::DESCS[..],
+                    into_settings_map(&config.editor),
+                ),
+                (
+                    "UI",
+                    &UIConfig::FIELDS[..],
+                    &UIConfig::DESCS[..],
+                    into_settings_map(&config.ui),
+                ),
+                (
+                    "Terminal",
+                    &TerminalConfig::FIELDS[..],
+                    &TerminalConfig::DESCS[..],
+                    into_settings_map(&config.terminal),
+                ),
+            ] {
+                let pos = cx.create_rw_signal(Point::new(0.0, item_height_accum));
+                data_items.push_back(SettingsItem {
+                    kind: kind.to_string(),
+                    name: "".to_string(),
+                    field: "".to_string(),
+                    filter_text: "".to_string(),
+                    description: "".to_string(),
+                    value: SettingsValue::Empty,
+                    serde_value: Value::Null,
+                    pos,
+                    size: cx.create_rw_signal(Size::ZERO),
+                    header: true,
+                });
+                data_kinds.push_back((kind.to_string(), pos));
+                for (name, desc) in fields.iter().zip(descs.iter()) {
+                    let field = name.replace('_', "-");
+
+                    let (value, serde_value) = if let Some(dropdown) =
+                        config.get_dropdown_info(&kind.to_lowercase(), &field)
+                    {
+                        let index = dropdown.active_index;
+                        (
+                            SettingsValue::Dropdown(dropdown),
+                            Value::Number(index.into()),
+                        )
+                    } else {
+                        let value = settings_map.remove(&field).unwrap();
+                        (SettingsValue::from(value.clone()), value)
+                    };
+
+                    let name = format!(
+                        "{kind}: {}",
+                        name.replace('_', " ").to_title_case()
+                    );
+                    let kind = kind.to_lowercase();
+                    let filter_text = format!("{kind} {name} {desc}").to_lowercase();
+                    let filter_text =
+                        format!("{filter_text}{}", filter_text.replace(' ', ""));
+                    data_items.push_back(SettingsItem {
+                        kind,
+                        name,
+                        field,
+                        filter_text,
+                        description: desc.to_string(),
+                        value,
+                        pos: cx.create_rw_signal(Point::ZERO),
+                        size: cx.create_rw_signal(Size::ZERO),
+                        serde_value,
+                        header: false,
+                    });
+                    item_height_accum += 50.0;
+                }
+            }
+
+            filtered_items.set(data_items.clone());
+            items.set(data_items);
+
             let plugins = installed_plugin.get();
-            let mut items = im::Vector::new();
-            let mut kinds = im::Vector::new();
+            let mut setting_items = im::Vector::new();
+            let mut plugin_kinds_tmp = im::Vector::new();
             for (_, volt) in plugins {
                 let meta = volt.meta.get();
                 let kind = meta.name;
@@ -234,18 +249,19 @@ impl SettingsData {
                 if let Some(config) = meta.config {
                     let pos =
                         cx.create_rw_signal(Point::new(0.0, item_height_accum));
-                    items.push_back(SettingsItem {
+                    setting_items.push_back(SettingsItem {
                         kind: meta.display_name.clone(),
                         name: "".to_string(),
                         field: "".to_string(),
                         filter_text: "".to_string(),
                         description: "".to_string(),
                         value: SettingsValue::Empty,
+                        serde_value: Value::Null,
                         pos,
                         size: cx.create_rw_signal(Size::ZERO),
                         header: true,
                     });
-                    kinds.push_back((meta.display_name.clone(), pos));
+                    plugin_kinds_tmp.push_back((meta.display_name.clone(), pos));
 
                     {
                         let mut local_items = Vec::new();
@@ -279,22 +295,24 @@ impl SettingsData {
                                 value,
                                 pos: cx.create_rw_signal(Point::ZERO),
                                 size: cx.create_rw_signal(Size::ZERO),
+                                serde_value: Value::Null,
                                 header: false,
                             };
                             local_items.push(item);
                             item_height_accum += 50.0;
                         }
                         local_items.sort_by_key(|i| i.name.clone());
-                        items.extend(local_items.into_iter());
+                        setting_items.extend(local_items.into_iter());
                     }
                 }
             }
-            plugin_items.set(items);
-            plugin_kinds.set(kinds);
+            plugin_items.set(setting_items);
+            plugin_kinds.set(plugin_kinds_tmp);
+            kinds.set(data_kinds);
         });
 
         Self {
-            filtered_items: cx.create_rw_signal(items.clone()),
+            filtered_items,
             plugin_items,
             plugin_kinds,
             items,
@@ -319,16 +337,15 @@ pub fn settings_view(
     let search_editor = editors.make_local(cx, common);
     let doc = search_editor.doc_signal();
 
-    let items = settings_data.items.clone();
-    let kinds = settings_data.kinds.clone();
+    let items = settings_data.items;
+    let kinds = settings_data.kinds;
     let filtered_items_signal = settings_data.filtered_items;
     create_effect(move |_| {
         let doc = doc.get();
         let pattern = doc.buffer.with(|b| b.to_string().to_lowercase());
         let plugin_items = settings_data.plugin_items.get();
-
+        let mut items = items.get();
         if pattern.is_empty() {
-            let mut items = items.clone();
             items.extend(plugin_items);
             filtered_items_signal.set(items);
             return;
@@ -353,7 +370,6 @@ pub fn settings_view(
     let scroll_pos = create_rw_signal(Point::ZERO);
 
     let current_kind = {
-        let kinds = kinds.clone();
         create_memo(move |_| {
             let scroll_pos = scroll_pos.get();
             let scroll_y = scroll_pos.y + 30.0;
@@ -365,6 +381,7 @@ pub fn settings_view(
                 }
             }
 
+            let kinds = kinds.get();
             for (kind, pos) in kinds.iter().rev() {
                 if pos.get_untracked().y < scroll_y {
                     return kind.to_string();
@@ -416,7 +433,7 @@ pub fn settings_view(
     let switcher = || {
         stack((
             dyn_stack(
-                move || kinds.clone(),
+                move || kinds.get().clone(),
                 |(k, _)| k.clone(),
                 move |(k, pos)| switcher_item(k, Box::new(move || Some(pos)), 0.0),
             )
@@ -472,7 +489,7 @@ pub fn settings_view(
                 TextInputBuilder::new()
                     .build_editor(search_editor)
                     .placeholder(|| "Search Settings".to_string())
-                    .keyboard_navigatable()
+                    .keyboard_navigable()
                     .style(move |s| {
                         s.width_pct(100.0)
                             .border_radius(6.0)
@@ -488,7 +505,13 @@ pub fn settings_view(
                 scroll({
                     dyn_stack(
                         move || filtered_items_signal.get(),
-                        |item| (item.kind.clone(), item.name.clone()),
+                        |item| {
+                            (
+                                item.kind.clone(),
+                                item.name.clone(),
+                                item.serde_value.clone(),
+                            )
+                        },
                         move |item| {
                             settings_item_view(
                                 editors,
@@ -525,7 +548,7 @@ fn settings_item_view(
     editors: Editors,
     settings_data: SettingsData,
     item: SettingsItem,
-) -> impl View {
+) -> impl View + use<> {
     let config = settings_data.common.config;
 
     let is_ticked = if let SettingsValue::Bool(is_ticked) = &item.value {
@@ -616,7 +639,7 @@ fn settings_item_view(
                 });
 
                 text_input_view
-                    .keyboard_navigatable()
+                    .keyboard_navigable()
                     .style(move |s| {
                         s.width(300.0).border(1.0).border_radius(6.0).border_color(
                             config.get().color(LapceColor::LAPCE_BORDER),
@@ -808,8 +831,6 @@ fn color_section_list(
                 .line_height(2.0)
         }),
         virtual_stack(
-            VirtualDirection::Vertical,
-            VirtualItemSize::Fixed(Box::new(move || text_height.get() + 24.0)),
             move || BTreeMapVirtualList(list()),
             move |(key, _)| (key.to_owned()),
             move |(key, value)| {
@@ -920,7 +941,7 @@ fn color_section_list(
                     text(&key).style(move |s| {
                         s.width(max_width.get()).margin_left(20).margin_right(10)
                     }),
-                    text_input_view.keyboard_navigatable().style(move |s| {
+                    text_input_view.keyboard_navigable().style(move |s| {
                         s.width(150.0)
                             .margin_vert(6)
                             .border(1)
@@ -1002,6 +1023,7 @@ fn color_section_list(
                 .style(|s| s.items_center())
             },
         )
+        .item_size_fixed(move || text_height.get() + 24.0)
         .style(|s| s.flex_col().padding_right(20)),
     ))
     .style(|s| s.flex_col())
@@ -1054,12 +1076,48 @@ pub fn theme_color_settings_view(
         max_width
     });
 
+    let cx = Scope::current();
+    let search_editor = editors.make_local(cx, common.clone());
+    let buffer = search_editor.doc_signal().get_untracked().buffer;
+
     scroll(
         stack((
+            container({
+                TextInputBuilder::new()
+                    .build_editor(search_editor)
+                    .placeholder(|| "Search Settings".to_string())
+                    .keyboard_navigable()
+                    .style(move |s| {
+                        s.width_pct(100.0)
+                            .border_radius(6.0)
+                            .border(1.0)
+                            .border_color(
+                                config.get().color(LapceColor::LAPCE_BORDER),
+                            )
+                    })
+                    .request_focus(|| {})
+            })
+            .style(|s| s.padding_vert(20.0).padding_horiz(20.0)),
             color_section_list(
                 "base",
                 "Base Colors",
-                move || config.with(|c| c.color_theme.base.key_values()),
+                move || {
+                    let filter = buffer.get().text().to_string();
+                    config.with(|c| {
+                        c.color_theme
+                            .base
+                            .0
+                            .iter()
+                            .filter_map(|x| {
+                                if x.0.contains(&filter) {
+                                    Some((x.0.clone(), x.1.clone()))
+                                } else {
+                                    None
+                                }
+                            })
+                            .collect::<BTreeMap<String, String>>()
+                    })
+                },
                 max_width,
                 text_height,
                 editors,
@@ -1068,7 +1126,22 @@ pub fn theme_color_settings_view(
             color_section_list(
                 "syntax",
                 "Syntax Colors",
-                move || config.with(|c| c.color_theme.syntax.clone()),
+                move || {
+                    let filter = buffer.get().text().to_string();
+                    config.with(|c| {
+                        c.color_theme
+                            .syntax
+                            .iter()
+                            .filter_map(|x| {
+                                if x.0.contains(&filter) {
+                                    Some((x.0.clone(), x.1.clone()))
+                                } else {
+                                    None
+                                }
+                            })
+                            .collect::<BTreeMap<String, String>>()
+                    })
+                },
                 max_width,
                 text_height,
                 editors,
@@ -1077,7 +1150,22 @@ pub fn theme_color_settings_view(
             color_section_list(
                 "ui",
                 "UI Colors",
-                move || config.with(|c| c.color_theme.ui.clone()),
+                move || {
+                    let filter = buffer.get().text().to_string();
+                    config.with(|c| {
+                        c.color_theme
+                            .ui
+                            .iter()
+                            .filter_map(|x| {
+                                if x.0.contains(&filter) {
+                                    Some((x.0.clone(), x.1.clone()))
+                                } else {
+                                    None
+                                }
+                            })
+                            .collect::<BTreeMap<String, String>>()
+                    })
+                },
                 max_width,
                 text_height,
                 editors,
@@ -1097,7 +1185,7 @@ fn dropdown_view(
     expanded: RwSignal<bool>,
     window_size: RwSignal<Size>,
     config: ReadSignal<Arc<LapceConfig>>,
-) -> impl View {
+) -> impl View + use<> {
     let window_origin = create_rw_signal(Point::ZERO);
     let size = create_rw_signal(Size::ZERO);
     let overlay_id = create_rw_signal(None);
@@ -1180,7 +1268,7 @@ fn dropdown_view(
             .width(250.0)
             .line_height(1.8)
     })
-    .keyboard_navigatable()
+    .keyboard_navigable()
     .on_event_stop(EventListener::FocusGained, move |_| {
         dropdown_input_focus.set(true);
     })
@@ -1209,7 +1297,7 @@ fn dropdown_scroll(
     input_size: RwSignal<Size>,
     window_size: RwSignal<Size>,
     config: ReadSignal<Arc<LapceConfig>>,
-) -> impl View {
+) -> impl View + use<> {
     dropdown_scroll_focus.set(true);
 
     let kind = item.kind.clone();
@@ -1251,7 +1339,7 @@ fn dropdown_scroll(
             .max_height(200.0)
             .set(PropagatePointerWheel, false)
     })
-    .keyboard_navigatable()
+    .keyboard_navigable()
     .request_focus(|| {})
     .on_event_stop(EventListener::FocusGained, move |_| {
         dropdown_scroll_focus.set(true);
