@@ -4,20 +4,22 @@ use alacritty_terminal::{
     grid::Dimensions,
     index::Side,
     selection::{Selection, SelectionType},
-    term::{cell::Flags, test::TermSize, RenderableContent},
+    term::{RenderableContent, cell::Flags, test::TermSize},
 };
 use floem::{
+    Renderer, View, ViewId,
     context::{EventCx, PaintCx},
     event::{Event, EventPropagation},
+    kurbo::Stroke,
     peniko::{
-        kurbo::{Point, Rect, Size},
         Color,
+        kurbo::{Point, Rect, Size},
     },
     pointer::PointerInputEvent,
-    reactive::{create_effect, ReadSignal, RwSignal, SignalGet, SignalWith},
+    prelude::SignalTrack,
+    reactive::{ReadSignal, RwSignal, SignalGet, SignalWith, create_effect},
     text::{Attrs, AttrsList, FamilyOwned, TextLayout, Weight},
     views::editor::{core::register::Clipboard, text::SystemClipboard},
-    Renderer, View, ViewId,
 };
 use lapce_core::mode::Mode;
 use lapce_rpc::{proxy::ProxyRpcHandler, terminal::TermId};
@@ -29,7 +31,7 @@ use unicode_width::UnicodeWidthChar;
 use super::{panel::TerminalPanelData, raw::RawTerminal};
 use crate::{
     command::InternalCommand,
-    config::{color::LapceColor, LapceConfig},
+    config::{LapceConfig, color::LapceColor},
     debug::RunDebugProcess,
     editor::location::{EditorLocation, EditorPosition},
     listener::Listener,
@@ -377,7 +379,7 @@ impl TerminalView {
             if cell.flags.contains(Flags::DIM)
                 || cell.flags.contains(Flags::DIM_BOLD)
             {
-                fg = fg.with_alpha_factor(0.66);
+                fg = fg.multiply_alpha(0.66);
             }
 
             if inverse {
@@ -411,7 +413,7 @@ impl TerminalView {
             }
 
             if cell.c != ' ' && cell.c != '\t' {
-                let mut attrs = attrs.color(fg);
+                let mut attrs = attrs.clone().color(fg);
                 if bold {
                     attrs = attrs.weight(Weight::BOLD);
                 }
@@ -467,13 +469,13 @@ impl TerminalView {
             if self.is_focused {
                 cx.fill(&rect, cursor_color, 0.0);
             } else {
-                cx.stroke(&rect, cursor_color, 1.0);
+                cx.stroke(&rect, cursor_color, &Stroke::new(1.0));
             }
         }
 
         for (char, attr, x, y) in &line_content.chars {
             let mut text_layout = TextLayout::new();
-            text_layout.set_text(&char.to_string(), AttrsList::new(*attr));
+            text_layout.set_text(&char.to_string(), AttrsList::new(attr.clone()));
             cx.draw_text(&text_layout, Point::new(*x, *y));
         }
     }
@@ -606,7 +608,7 @@ impl View for TerminalView {
         let layout = self.id.get_layout().unwrap_or_default();
         let size = layout.size;
         let size = Size::new(size.width as f64, size.height as f64);
-        if size.is_empty() {
+        if size.is_zero_area() {
             return None;
         }
         if size != self.size {
