@@ -1,17 +1,19 @@
 use std::{rc::Rc, sync::Arc};
 
 use floem::{
+    Renderer, View, ViewId,
     action::{set_ime_allowed, set_ime_cursor_area},
     context::EventCx,
     event::{Event, EventListener, EventPropagation},
+    kurbo::Stroke,
     peniko::{
-        kurbo::{Line, Point, Rect, Size, Vec2},
         Color,
+        kurbo::{Line, Point, Rect, Size, Vec2},
     },
     prop_extractor,
     reactive::{
-        create_effect, create_memo, create_rw_signal, Memo, ReadSignal, RwSignal,
-        Scope, SignalGet, SignalUpdate, SignalWith,
+        Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        create_effect, create_memo, create_rw_signal,
     },
     style::{
         CursorStyle, FontFamily, FontSize, FontStyle, FontWeight, LineHeight,
@@ -21,7 +23,6 @@ use floem::{
     text::{Attrs, AttrsList, FamilyOwned, TextLayout},
     unit::PxPct,
     views::Decorators,
-    Renderer, View, ViewId,
 };
 use lapce_core::{
     buffer::rope_text::RopeText,
@@ -31,9 +32,9 @@ use lapce_core::{
 use lapce_xi_rope::Rope;
 
 use crate::{
-    config::{color::LapceColor, LapceConfig},
+    config::{LapceConfig, color::LapceColor},
     doc::Doc,
-    editor::{view::editor_style, DocSignal, EditorData},
+    editor::{DocSignal, EditorData, view::editor_style},
     keypress::KeyPressFocus,
     main_split::Editors,
     window_tab::CommonData,
@@ -392,7 +393,7 @@ impl TextInput {
             } else {
                 self.content.as_str()
             },
-            AttrsList::new(attrs),
+            AttrsList::new(attrs.clone()),
         );
         self.text_layout.set(Some(text_layout));
 
@@ -401,7 +402,7 @@ impl TextInput {
             self.style
                 .color()
                 .unwrap_or(Color::BLACK)
-                .with_alpha_factor(0.5),
+                .multiply_alpha(0.5),
         );
         placeholder_text_layout.set_text(&self.placeholder, AttrsList::new(attrs));
         self.placeholder_text_layout = Some(placeholder_text_layout);
@@ -754,7 +755,11 @@ impl View for TextInput {
                         end_point.y + end_position.glyph_descent,
                     ),
                 );
-                cx.stroke(&line, config.color(LapceColor::EDITOR_FOREGROUND), 1.0);
+                cx.stroke(
+                    &line,
+                    config.color(LapceColor::EDITOR_FOREGROUND),
+                    &Stroke::new(1.0),
+                );
             }
 
             if !self.hide_cursor.get_untracked()
@@ -781,7 +786,7 @@ impl View for TextInput {
                 cx.stroke(
                     &line,
                     self.config.get_untracked().color(LapceColor::EDITOR_CARET),
-                    2.0,
+                    &Stroke::new(2.0),
                 );
             }
 
