@@ -1,14 +1,14 @@
 use std::{path::PathBuf, rc::Rc, sync::Arc};
 
 use floem::{
+    ViewId,
     action::TimerToken,
     peniko::kurbo::{Point, Size},
     reactive::{
-        use_context, Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate,
-        SignalWith,
+        Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        use_context,
     },
     window::WindowId,
-    ViewId,
 };
 use serde::{Deserialize, Serialize};
 
@@ -203,13 +203,19 @@ impl WindowData {
         match cmd {
             WindowCommand::SetWorkspace { workspace } => {
                 let db: Arc<LapceDb> = use_context().unwrap();
-                let _ = db.update_recent_workspace(&workspace);
+                if let Err(err) = db.update_recent_workspace(&workspace) {
+                    tracing::error!("{:?}", err);
+                }
 
                 let active = self.active.get_untracked();
                 self.window_tabs.with_untracked(|window_tabs| {
                     if !window_tabs.is_empty() {
                         let active = window_tabs.len().saturating_sub(1).min(active);
-                        let _ = db.insert_window_tab(window_tabs[active].1.clone());
+                        if let Err(err) =
+                            db.insert_window_tab(window_tabs[active].1.clone())
+                        {
+                            tracing::error!("{:?}", err);
+                        }
                     }
                 });
 
@@ -234,7 +240,9 @@ impl WindowData {
             }
             WindowCommand::NewWorkspaceTab { workspace, end } => {
                 let db: Arc<LapceDb> = use_context().unwrap();
-                let _ = db.update_recent_workspace(&workspace);
+                if let Err(err) = db.update_recent_workspace(&workspace) {
+                    tracing::error!("{:?}", err);
+                }
 
                 let window_tab = Rc::new(WindowTabData::new(
                     self.scope,
@@ -275,7 +283,9 @@ impl WindowData {
                         let (_, old_window_tab) = window_tabs.remove(index);
                         old_window_tab.proxy.shutdown();
                         let db: Arc<LapceDb> = use_context().unwrap();
-                        let _ = db.save_window_tab(old_window_tab);
+                        if let Err(err) = db.save_window_tab(old_window_tab) {
+                            tracing::error!("{:?}", err);
+                        }
                     }
                 });
 
