@@ -1,5 +1,5 @@
 use std::{
-    collections::{hash_map::Entry, HashMap, HashSet},
+    collections::{HashMap, HashSet, hash_map::Entry},
     fmt::Write,
     path::Path,
     str::FromStr,
@@ -9,7 +9,7 @@ use lapce_rpc::style::{LineStyle, Style};
 use once_cell::sync::Lazy;
 use regex::Regex;
 use strum_macros::{AsRefStr, Display, EnumMessage, EnumString, IntoStaticStr};
-use tracing::{event, Level};
+use tracing::{Level, event};
 use tree_sitter::{Point, TreeCursor};
 
 use crate::{
@@ -36,11 +36,11 @@ impl Indent {
         match self {
             Indent::Tab => "\u{0009}",
             #[allow(clippy::wildcard_in_or_patterns)]
-            Indent::Space(v) => {
-                match v {
-                    2 => "\u{0020}\u{0020}",
-                    4 => "\u{0020}\u{0020}\u{0020}\u{0020}",
-                    8 | _ => "\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}",
+            Indent::Space(v) => match v {
+                2 => "\u{0020}\u{0020}",
+                4 => "\u{0020}\u{0020}\u{0020}\u{0020}",
+                8 | _ => {
+                    "\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}\u{0020}"
                 }
             },
         }
@@ -495,7 +495,7 @@ const LANGUAGES: &[SyntaxProperties] = &[
         id: LapceLanguage::Bash,
         indent: Indent::space(2),
         files: &[],
-        extensions: &["bash"],
+        extensions: &["bash", "sh"],
         comment: comment_properties!("#"),
         tree_sitter: TreeSitterProperties::DEFAULT,
     },
@@ -706,7 +706,7 @@ const LANGUAGES: &[SyntaxProperties] = &[
         id: LapceLanguage::Diff,
         indent: Indent::tab(),
         files: &[],
-        extensions: &[],
+        extensions: &["diff", "patch"],
         comment: comment_properties!(),
         tree_sitter: TreeSitterProperties::DEFAULT,
     },
@@ -1765,10 +1765,16 @@ impl LapceLanguage {
         let grammar_fn_name = self.grammar_fn_name();
 
         if let Some(grammars_dir) = Directory::grammars_directory() {
-            if let Ok(grammar) =
-                self::load_grammar(&grammar_name, &grammar_fn_name, &grammars_dir)
+            match self::load_grammar(&grammar_name, &grammar_fn_name, &grammars_dir)
             {
-                return Some(grammar);
+                Ok(grammar) => {
+                    return Some(grammar);
+                }
+                Err(err) => {
+                    if self != &LapceLanguage::PlainText {
+                        tracing::error!("{:?} {:?}", self, err);
+                    }
+                }
             }
         };
 
@@ -1830,7 +1836,10 @@ impl LapceLanguage {
         match HighlightConfiguration::new(grammar, &query, &injection, "") {
             Ok(x) => Ok(x),
             Err(x) => {
-                let str = format!("Encountered {x:?} while trying to construct HighlightConfiguration for {}", self.name());
+                let str = format!(
+                    "Encountered {x:?} while trying to construct HighlightConfiguration for {}",
+                    self.name()
+                );
                 event!(Level::ERROR, "{str}");
                 Err(HighlightIssue::Error(str))
             }
